@@ -321,8 +321,11 @@ class Screen(object):
 
     def init_git_show(self, rev_to_show=None):
         """Setup for a git show"""
-        _, line_meta = self._get_cursor_line(include_meta=True)
-        rev = rev_to_show if rev_to_show else line_meta.sha
+        rev = rev_to_show
+        if not rev:
+            _, line_meta = self._get_cursor_line(include_meta=True)
+            rev = line_meta.sha
+
         if rev == '0'*len(rev):
             uncommitted_show_msg = 'Cannot git show an uncommitted change!'
             logging.debug(uncommitted_show_msg)
